@@ -22,16 +22,30 @@ func main() {
 		appName := flag.Arg(0)
 		processType := flag.Arg(1)
 		err = appjson.TriggerAppJSONProcessDeployParallelism(appName, processType)
+	case "core-post-deploy":
+		appName := flag.Arg(0)
+		err = appjson.TriggerCorePostDeploy(appName)
+	case "core-post-extract":
+		appName := flag.Arg(0)
+		sourceWorkDir := flag.Arg(1)
+		err = appjson.TriggerCorePostExtract(appName, sourceWorkDir)
 	case "install":
 		err = appjson.TriggerInstall()
 	case "post-app-clone-setup":
 		oldAppName := flag.Arg(0)
 		newAppName := flag.Arg(1)
 		err = appjson.TriggerPostAppCloneSetup(oldAppName, newAppName)
+	case "post-app-rename":
+		oldAppName := flag.Arg(0)
+		newAppName := flag.Arg(1)
+		err = appjson.TriggerPostAppRename(oldAppName, newAppName)
 	case "post-app-rename-setup":
 		oldAppName := flag.Arg(0)
 		newAppName := flag.Arg(1)
 		err = appjson.TriggerPostAppRenameSetup(oldAppName, newAppName)
+	case "post-create":
+		appName := flag.Arg(0)
+		err = appjson.TriggerPostCreate(appName)
 	case "post-delete":
 		appName := flag.Arg(0)
 		err = appjson.TriggerPostDelete(appName)
