@@ -116,12 +116,7 @@ func TriggerInstall() error {
 		return fmt.Errorf("Unable to install the ps plugin: %s", err.Error())
 	}
 
-	directory := filepath.Join(common.MustGetEnv("DOKKU_LIB_ROOT"), "data", "ps")
-	if err := os.MkdirAll(directory, 0755); err != nil {
-		return err
-	}
-
-	if err := common.SetPermissions(directory, 0755); err != nil {
+	if err := common.SetupAppData("ps"); err != nil {
 		return err
 	}
 
@@ -130,6 +125,12 @@ func TriggerInstall() error {
 		return nil
 	}
 
+	for _, appName := range apps {
+		if err := common.CreateAppDataDirectory("ps", appName); err != nil {
+			return err
+		}
+	}
+
 	for _, appName := range apps {
 		policies, err := getRestartPolicy(appName)
 		if err != nil {
@@ -148,23 +149,11 @@ func TriggerInstall() error {
 	for _, appName := range apps {
 		dokkuScaleFile := filepath.Join(common.AppRoot(appName), "DOKKU_SCALE")
 		if common.FileExists(dokkuScaleFile) {
-			processTuples, err := common.FileToSlice(dokkuScaleFile)
-			if err != nil {
-				return err
-			}
-
-			if err := scaleSet(appName, true, false, processTuples); err != nil {
-				return err
-			}
-
 			os.Remove(dokkuScaleFile)
 		}
 
 		dokkuScaleExtracted := filepath.Join(common.AppRoot(appName), "DOKKU_SCALE.extracted")
 		if common.FileExists(dokkuScaleExtracted) {
-			if err := common.PropertyWrite("ps", appName, "can-scale", strconv.FormatBool(false)); err != nil {
-				return err
-			}
 			os.Remove(dokkuScaleExtracted)
 		}
 	}
@@ -188,12 +177,15 @@ func TriggerPostAppCloneSetup(oldAppName string, newAppName string) error {
 		return err
 	}
 
-	// TODO: Copy data dir
-	return nil
+	return common.CloneAppData("ps", oldAppName, newAppName)
 }
 
 // TriggerPostAppRename rebuilds the renamed app
 func TriggerPostAppRename(oldAppName string, newAppName string) error {
+	if err := common.MigrateAppDataDirectory("ps", oldAppName, newAppName); err != nil {
+		return err
+	}
+
 	if os.Getenv("SKIP_REBUILD") == "true" {
 		return nil
 	}
@@ -211,8 +203,7 @@ func TriggerPostAppRenameSetup(oldAppName string, newAppName string) error {
 		return err
 	}
 
-	// TODO: Move data dir
-	return nil
+	return common.CloneAppData("ps", oldAppName, newAppName)
 }
 
 // TriggerPostCreate ensures apps have a default restart policy
@@ -222,12 +213,7 @@ func TriggerPostCreate(appName string) error {
 		return err
 	}
 
-	directory := filepath.Join(common.MustGetEnv("DOKKU_LIB_ROOT"), "data", "ps", appName)
-	if err := os.MkdirAll(directory, 0755); err != nil {
-		return err
-	}
-
-	if err := common.SetPermissions(directory, 0755); err != nil {
+	if err := common.CreateAppDataDirectory("ps", appName); err != nil {
 		return err
 	}
 
@@ -242,8 +228,7 @@ func TriggerPostCreate(appName string) error {
 
 // TriggerPostDelete destroys the ps properties for a given app container
 func TriggerPostDelete(appName string) error {
-	directory := filepath.Join(common.MustGetEnv("DOKKU_LIB_ROOT"), "data", "ps", appName)
-	dataErr := os.RemoveAll(directory)
+	dataErr := common.RemoveAppDataDirectory("ps", appName)
 	propertyErr := common.PropertyDestroy("ps", appName)
 
 	if dataErr != nil {
@@ -276,13 +261,11 @@ func TriggerPreDeploy(appName string, imageTag string) error {
 
 // TriggerProcfileGetCommand fetches a command from the procfile
 func TriggerProcfileGetCommand(appName string, processType string, port int) error {
-	existingProcfile := getProcfilePath(appName)
-	processSpecificProcfile := fmt.Sprintf("%s.%s", existingProcfile, os.Getenv("DOKKU_PID"))
-	if common.FileExists(fmt.Sprintf("%s.missing", processSpecificProcfile)) {
+	if !hasProcfile(appName) {
 		return nil
 	}
 
-	command, err := getProcfileCommand(getProcessSpecificProcfile(appName), processType, port)
+	command, err := getProcfileCommand(getProcessSpecificProcfilePath(appName), processType, port)
 	if err != nil {
 		return err
 	}
